<?php

App::uses('FaqsAppModel', 'Faqs.Model');

class Faq extends FaqsAppModel {

	public $displayField = 'question';

	public $belongsTo = array(
		'FaqCategory' => array('className' => 'Faqs.FaqCategory')
	);

	public $validate = array(
		'question' => array(
			'required' => array(
				'rule' => 'notBlank',
				'message' => 'Please add a question'
			),
			'maxLength' => array(
				'rule' => array('maxLength', 250),
				'message' => 'No more than 250 characters long'
			)
		),
		'answer' => array(
			'required' => array(
				'rule' => 'notBlank',
				'message' => 'Please add an answer'
			)
		),
		'sequence' => array(
			'required' => array(
				'rule' => 'notBlank',
				'message' => 'Please add a sequence'
			),
			'integer' => array(
				'rule' => array('naturalNumber', true),
				'message' => 'Integer values only'
			)
		)
	);

	public $order = array(
		'Faq.sequence' => 'asc',
		'Faq.question' => 'asc'
	);

	/**
	 * Gets the FAQs grouped by the FAQ categories in sequential order.
	 *
	 * @return array
	 */
	public function getFaqs() {
		$params = [
			'conditions' => [
				'Faq.is_active' => true
			],
			'order' => [
				'Faq.sequence' => 'asc',
				'Faq.question' => 'asc'
			]
		];

		if (Configure::read('Faqs.has_categories') === true) {
			$params['contain']['FaqCategory'] = [
				'conditions' => ['FaqCategory.is_active' => true]
			];

			$params['order'][] = 'FaqCategory.sequence asc';
			$params['order'][] = 'FaqCategory.name asc';
		}

		$results = $this->find('all', $params);

		$data = array();

		foreach ($results as $result) {
			if (Configure::read('Faqs.has_categories') === true) {
				$id = $result['FaqCategory']['id'];

				if (empty($data[$id])) {
					$data[$id]['FaqCategory'] = $result['FaqCategory'];
				}
			} else {
				$id = 0;
			}

			$data[$id]['Faq'][] = $result['Faq'];
		}

		return $data;
	}

}
